aboutsummaryrefslogtreecommitdiff
path: root/src/backend/access/common/attmap.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/access/common/attmap.c')
-rw-r--r--src/backend/access/common/attmap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/backend/access/common/attmap.c b/src/backend/access/common/attmap.c
index 0805c4121ee..934397c9e58 100644
--- a/src/backend/access/common/attmap.c
+++ b/src/backend/access/common/attmap.c
@@ -315,13 +315,13 @@ check_attrmap_match(TupleDesc indesc,
/*
* If it's a dropped column and the corresponding input column is also
* dropped, we don't need a conversion. However, attlen and attalign
* must agree.
*/
if (attrMap->attnums[i] == 0 &&
inatt->attisdropped &&
inatt->attlen == outatt->attlen &&
- inatt->attalign == outatt->attalign)
+ inatt->attalignby == outatt->attalignby)
continue;
return false;
@@ -315,13 +315,13 @@ check_attrmap_match(TupleDesc indesc,
/*
* If it's a dropped column and the corresponding input column is also
- * dropped, we don't need a conversion. However, attlen and attalign
- * must agree.
+ * dropped, we don't need a conversion. However, attlen and
+ * attalignby must agree.
*/
if (attrMap->attnums[i] == 0 &&